@@ -57,8 +57,7 @@ def game(incoming):
             if guess_added == comp_added and guess_multi == comp_multi:
                 return True
             elif lives < 1:
-                print('\nAnswer: ' + str(rannum1) + ' ' + str(rannum2) + ' ' + str(rannum3) + ' ' + str(rannum4))
-                return False
+                return False, '\nAnswer: ' + str(rannum1) + ' ' + str(rannum2) + ' ' + str(rannum3) + ' ' + str(rannum4)
             else:
                 print('Wrong, try again...')
 
@@ -78,6 +77,7 @@ def main_func():
         level += 1
         os.system('cls')
 
+    print(gamestatus[1])
     print('Game Over. Your max level was ' + str(level))
 
 
